package de.fitconnect.dependency;

import com.google.inject.AbstractModule;
import com.google.inject.Provides;
import fitconnect.api.services.Sender;
import fitconnect.api.services.Subscriber;
import fitconnect.api.services.auth.OAuthService;
import fitconnect.api.services.crypto.CryptoService;
import fitconnect.api.services.validation.CertificateValidator;
import fitconnect.api.services.validation.MetadataValidator;
import fitconnect.impl.SubmissionSender;
import fitconnect.impl.SubmissionSubscriber;
import fitconnect.impl.auth.MonoPublisherOAuthService;
import fitconnect.impl.crypto.JWECryptoService;
import fitconnect.impl.validation.KeyValidator;
import fitconnect.impl.validation.MetadataSubmissionValidator;

public class SdkModule extends AbstractModule {

    @Override
    protected void configure() {
        bind(CryptoService.class).to(JWECryptoService.class);
        bind(CertificateValidator.class).to(KeyValidator.class);
        bind(MetadataValidator.class).to(MetadataSubmissionValidator.class);

        bind(Sender.class).to(SubmissionSender.class);
        bind(Subscriber.class).to(SubmissionSubscriber.class);
    }

    @Provides
    static OAuthService provideOAuthService() {
        return new MonoPublisherOAuthService("https://auth-testing.fit-connect.fitko.dev/token");
    }

}
